# Changelog

## 3.0.0 (2024-09-18)

Full Changelog: [v2.0.0...v3.0.0](https://github.com/pilfo/rainbows/compare/v2.0.0...v3.0.0)

### Features

* **api:** update via SDK Studio ([801f471](https://github.com/pilfo/rainbows/commit/801f4715d5d4b53d3a5c6606d69fc806dfa2bf34))
* **api:** update via SDK Studio ([2ef1f5a](https://github.com/pilfo/rainbows/commit/2ef1f5a0ba9cf9993d7b933a00083d3ac81e6cbe))


### Chores

* go live ([#8](https://github.com/pilfo/rainbows/issues/8)) ([db4f167](https://github.com/pilfo/rainbows/commit/db4f167dd2593e08d687f18e66d98c7d6966e2cf))
* update SDK settings ([#10](https://github.com/pilfo/rainbows/issues/10)) ([133f843](https://github.com/pilfo/rainbows/commit/133f843e3e1c1bc242ef4bdc5c14044eaae7f6e1))

## 2.0.0 (2024-09-18)

Full Changelog: [v0.0.1-alpha.0...v2.0.0](https://github.com/pilfo/rainbows/compare/v0.0.1-alpha.0...v2.0.0)

### Chores

* go live ([#4](https://github.com/pilfo/rainbows/issues/4)) ([93cd5cd](https://github.com/pilfo/rainbows/commit/93cd5cd6ca0e8aa4d7dc46e25a8a59a3e3cb061a))
* update SDK settings ([#6](https://github.com/pilfo/rainbows/issues/6)) ([89c8d53](https://github.com/pilfo/rainbows/commit/89c8d53c10207c04b30a38352207e304da837b58))
